@@ -20,6 +20,22 @@ impl Writer {
         Writer { inner: Vec::new() }
     }
 
+    /// Write a cstring to the underlying vector
+    ///
+    /// # Example
+    /// ```rust
+    /// # use sshcerts::ssh::Writer;
+    /// let mut writer = Writer::new();
+    /// writer.write_cstring("AAAA");
+    /// let bytes = writer.into_bytes();
+    /// assert_eq!(bytes, vec![65, 65, 65, 65, 00]);
+    /// ```
+    pub fn write_cstring(&mut self, s: &str) {
+        let bytes = s.as_bytes();
+        self.inner.extend_from_slice(bytes);
+        self.inner.push(0x0);
+    }
+
     /// Writes a byte sequence to the underlying vector.
     /// The value is represented as a the byte sequence length,
     /// followed by the actual byte sequence.
@@ -39,6 +55,20 @@ impl Writer {
         self.inner.extend_from_slice(val);
     }
 
+    /// Writes a raw byte sequence to the underlying vector.e.
+    ///
+    /// # Example
+    /// ```rust
+    /// # use sshcerts::ssh::Writer;
+    /// let mut writer = Writer::new();
+    /// writer.write_raw_bytes(&[0, 0, 0, 42]);
+    /// let bytes = writer.into_bytes();
+    /// assert_eq!(bytes, vec![0, 0, 0, 42]);
+    /// ```
+    pub fn write_raw_bytes(&mut self, val: &[u8]) {
+        self.inner.extend_from_slice(val);
+    }
+
     /// Writes a `string` value to the underlying byte sequence.
     ///
     /// # Example
@@ -166,20 +196,40 @@ impl Writer {
     /// ```
     /// ```
     pub fn write_pub_key(&mut self, key: &PublicKey) {
+        let mut inner_writer = Writer::new();
+        inner_writer.write_string(key.key_type.name);
+        inner_writer.write_pub_key_data(key);
+
+        let pubkey_bytes = inner_writer.as_bytes();
+        self.write_bytes(pubkey_bytes);
+   }
+
+    /// Writes `PublicKey` data to the underlying byte sequence.
+    ///
+    /// # Example
+    /// ```
+    /// ```
+    pub fn write_pub_key_data(&mut self, key: &PublicKey) {
          // Write the public key
          match &key.kind {
-            PublicKeyKind::Ecdsa(key) => {
-                self.write_string(key.curve.identifier);
-                self.write_bytes(&key.key);
-            },
-            PublicKeyKind::Rsa(key) => {
-                self.write_mpint(&key.e);
-                self.write_mpint(&key.n);
-            },
-            PublicKeyKind::Ed25519(key) => {
-                self.write_bytes(&key.key);
+            PublicKeyKind::Rsa(ref k) => {
+                self.write_mpint(&k.e);
+                self.write_mpint(&k.n);
             }
-        };
+            PublicKeyKind::Ecdsa(ref k) => {
+                self.write_string(k.curve.identifier);
+                self.write_bytes(&k.key);
+                if key.key_type.is_sk {
+                    self.write_string(&k.sk_application.as_ref().unwrap());
+                }
+            }
+            PublicKeyKind::Ed25519(ref k) => {
+                self.write_bytes(&k.key);
+                if key.key_type.is_sk {
+                    self.write_string(&k.sk_application.as_ref().unwrap());
+                }
+            }
+        }
     }
 
     /// Converts the `Writer` into a byte sequence.
